@@ -38,9 +38,11 @@ def update_studio_category(category_id, name):
 # super_categoryid为空，创建一级目录
 def create_category(category_name, super_categoryid=None):
     # http://doc.bokecc.com/vod/dev/SparkAPI/spark10/
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://spark.bokecc.com/api/category/create"
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "name": category_name.encode('utf-8'),
         "format": "json"
     }
@@ -61,10 +63,12 @@ def create_category(category_name, super_categoryid=None):
 def update_category(category_id, category_name):
     # http://spark.bokecc.com/api/category/update
     # http://doc.bokecc.com/vod/dev/SparkAPI/spark10/
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://spark.bokecc.com/api/category/update"
     params_dict = {
         "categoryid": category_id,
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "name": category_name.encode('utf-8'),
         "format": "json"
     }
@@ -78,9 +82,11 @@ def update_category(category_id, category_name):
 # 创建直播间
 def create_room(room_name):
     # http://doc.bokecc.com/live/dev/liveapi/#toc_11
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://api.csslcloud.net/api/room/create"
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "name": room_name.encode('utf-8'),
         "desc": room_name.encode('utf-8'),
         "templatetype": "1",
@@ -107,9 +113,11 @@ def create_room(room_name):
 # 关闭直播间
 def close_room(room_id):
     # https://doc.bokecc.com/live/live_http.html
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://api.csslcloud.net/api/room/close"
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "roomid": room_id
 
     }
@@ -124,9 +132,11 @@ def close_room(room_id):
 
 # 开启直播间
 def open_room(room_id):
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://api.csslcloud.net/api/room/open"
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "roomid": room_id
 
     }
@@ -143,10 +153,12 @@ def open_room(room_id):
 # 获取直播间代码
 def get_room_code(room_id):
     # http://doc.bokecc.com/live/dev/liveapi/#toc_22
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://api.csslcloud.net/api/room/code"
     params_dict = {
         "roomid": room_id,
-        "userid": settings.COURSE_CC_USERID
+        "userid": settings.CC_CONFIG.user_id
     }
     qs = thqs(params_dict, 'live')
     url += "?" + qs
@@ -159,31 +171,22 @@ def get_room_code(room_id):
     return None
 
 
-# # 上传点播视频
-# def create_video(_file):
-#     videoid, userid, servicetype, metaurl, chunkurl = create_video_info()
-#     if not videoid:
-#         return None
-#     print('===========videoid=======')
-#     print(videoid)
-#     # result, msg, received = create_video_meta(videoid, userid, servicetype, metaurl, chunkurl)
-#     # if not result == 0:
-#     #     return None
-#     # create_video_chunk(_file, chunkurl, videoid)
-#     return None
-
 
 # 1.创建视频上传信息
-def create_video_info(title, filename, filesize, categoryid):
+def create_video_info(title, filename, filesize, categoryid=None):
     # http://doc.bokecc.com/vod/dev/uploadAPI/upload02/
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://spark.bokecc.com/api/video/create"
+    if not categoryid:
+        categoryid=settings.CC_CONFIG.category_id
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "title": title.encode('utf-8'),
         "description": filename.encode('utf-8'),
         "categoryid": categoryid,
         "filesize": filesize,
-        "notify_url": settings.COURSE_CC_VIDEO_CALLBACK_URL.encode('utf-8'),
+        "notify_url": settings.CC_CONFIG.video_callback_url.encode('utf-8'),
         "format": "json",
 
     }
@@ -194,13 +197,6 @@ def create_video_info(title, filename, filesize, categoryid):
     if res_json.has_key(u"uploadinfo"):
         return res_json
     return None
-    # info = res_json["uploadinfo"]
-    # videoid = info["videoid"]
-    # _userid = info["userid"]
-    # servicetype = info["servicetype"]
-    # metaurl = info["metaurl"]
-    # chunkurl = info["chunkurl"]
-    # print(metaurl)
 
 
 # 2 上传成功后记录用户video对应关系
@@ -221,100 +217,17 @@ def uplode_video_done(request):
     return JSONResponse(json.dumps(res, ensure_ascii=False))
 
 
-# 2.创建视频meta信息
-# def create_video_meta(videoid, userid, servicetype, metaurl, chunkurl):
-#     # http://doc.bokecc.com/vod/dev/uploadAPI/upload02/
-#     url = metaurl
-#     params_dict = {
-#         "uid": userid,
-#         "ccvid": videoid,
-#         "first": "1",
-#         "filename": "a",
-#         "md5": "qq",
-#         "filesize": "10",
-#         "servicetype": servicetype
-#     }
-#     print('===========videoid2=======')
-#     print(videoid)
-#     params_str = get_params_str(params_dict)
-#     url += "?" + get_hashed_query_string("video", params_str)
-#     res = http.http_get(url)
-#     res_json = str2json(res)
-#     print(res_json)
-#     if not res_json.has_key("result"):
-#         return None, None, None
-#
-#     result = res_json["result"]
-#     msg = res_json["msg"]
-#     received = res_json["received"]
-#     return result, msg, received
-#
-#
-# # 3.上传视频文件块CHUNK
-# def create_video_chunk(_file, chunkurl, videoid):
-#     # http://doc.bokecc.com/vod/dev/uploadAPI/upload02/
-#     url = chunkurl + "?ccvid=" + videoid + "&format=format"
-#     params_dict = {
-#         "ccvid": videoid,
-#         "format": "json"
-#
-#     }
-#     chunk_start = 1
-#     chunk_end = 10
-#     file_size = 100
-#
-#     res = post_video_chunk(url, _file, params_dict, chunk_start, chunk_end)
-#     print('=========')
-#     print(res)
-#     res_json = str2json(res)
-#     if res_json:
-#         if not res_json.has_key("result"):
-#             return None, None, None
-#
-#     return
-#
-#
-# class File():
-#     path = "/Users/bee/Downloads/1.mov"
-#     prefixLength = 3
-#
-#
-# def post_video_chunk(url, _file, params_dict, chunk_start, chunk_end):
-#     files = {'file': open("/Users/bee/Downloads/1.mov", 'rb')}
-#     file = open("/Users/bee/Downloads/1.mov", 'rb')
-#     r = requests.post(url, files=files)
-#
-#
-#     # files = {'file': File()}
-#     #
-#     # r = requests.post(url, files=files)
-#     # res_data = r.content
-#     #
-#     # parameters = urllib.urlencode(params_dict)
-#     # request = urllib2.Request(url)
-#     #
-#     # request.add_header('Content-Type', "multipart/form-data")
-#     # request.add_header('Content-Disposition', "form-data;name=file;filename=" + _file.name)
-#     # # request.add_header('Content-Type', 'application/octet-stream')
-#     # # request.add_header('Content-Type', 'application/x-www-form-urlencoded')
-#     # # request.add_header('Content-Type', 'application/octet-stream')
-#     # request.add_header('Content-Range',
-#     #                    'bytes ' + chunk_start.__str__() + '-' + chunk_end.__str__() + '/' + _file.size.__str__())
-#     # try:
-#     #     res_json = str2json(res_data)
-#     #     return res_json
-#     # except Exception as e:
-#     #     print(e)
-#     return None
 
 
 # 获取直播回放记录
 def get_live_watched():
     # http://doc.bokecc.com/live/dev/liveapi/#toc_26
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://api.csslcloud.net/api/statis/replay"
     now = get_now()
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "starttime": "2017-07-27 15:00",
         "endtime": "2017-07-27 19:00",
         "pageindex": "1",
@@ -333,10 +246,12 @@ def get_live_watched():
 # 获取视频播放代码
 def get_video_play_code(videoid):
     # http://doc.bokecc.com/vod/dev/SparkAPI/spark06/
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://spark.bokecc.com/api/video/playcode"
     params_dict = {
         "videoid": videoid,
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "player_width": "100%",
         "player_height": "40%",
         "auto_play": "true",
@@ -345,27 +260,48 @@ def get_video_play_code(videoid):
     }
     qs = thqs(params_dict, 'live')
     url += "?" + qs
-    print(url)
+    # print(url)
     res = http_get(url)
-    print(res)
+    # print(res)
     res_json = str2json(res)
-    print(res_json)
+    # print(res_json)
     return
 
 
-# 获取视频播放地址
+# 获取点播视频播放地址
 def get_video_str(video_id):
-    if settings.COURSE_VIDEO_PROVIDER_NAME == 'cc':
-        src = "https://p.bokecc.com/playhtml.bo?vid=" + video_id + "&siteid=" + settings.COURSE_CC_USERID + "&autoStart=false&playerid=" + settings.COURSE_CC_PLAYERID + "&playertype=1"
-        return src
+    if not hasattr(settings, "CC_CONFIG"):
+        return
+    src = "https://p.bokecc.com/playhtml.bo?vid=" + video_id + "&siteid=" + settings.CC_CONFIG.user_id + "&autoStart=false&playerid=" + settings.CC_CONFIG.player_id + "&playertype=1"
+    return src
+
+# 获取录播视频地址
+def get_live_str(video_id):
+    if not hasattr(settings, "CC_CONFIG"):
+        return
+    url="http://p.bokecc.com/api/mobile"
+    params_dict = {
+        "videoid": video_id,
+        "userid": settings.CC_CONFIG.user_id,
+        "format": "json",
+    }
+    qs = thqs(params_dict, 'video')
+    url += "?" + qs
+    res = http_get(url)
+    res_json = str2json(res)
+    if res_json.has_key("error"):
+        return None
+    return res_json["video"]["copy"][0]["playurl"]
 
 
 # 删除视频
 def delete_video(vodio_id):
     # http://doc.bokecc.com/vod/dev/SparkAPI/spark08/
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     url = "http://spark.bokecc.com/api/video/delete"
     params_dict = {
-        "userid": settings.COURSE_CC_USERID,
+        "userid": settings.CC_CONFIG.user_id,
         "videoid": vodio_id,
         "format": "json",
 
@@ -380,43 +316,44 @@ def delete_video(vodio_id):
     return
 
 
+
 # 获取某条视频某日的观看记录
-def get_video_play_logs(video_id, date):
-    # https://doc.bokecc.com/index.php?c=content&a=list&catid=295
-    url = "http://spark.bokecc.com/api/playlog/video/v2"
-    params_dict = {
-        "userid": settings.COURSE_CC_USERID,
-        "videoid": video_id,
-        "date": date,
-        "num_per_page": 5000,
-        "page": 1
-    }
-    qs = thqs(params_dict, 'video')
-    url += "?" + qs
-    res = http_get(url)
-    res_json = str2json(res)
-    if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
-        return res_json["total"], res_json["play_log"]
-    return None, None
+# def get_video_play_logs(video_id, date):
+#     # https://doc.bokecc.com/index.php?c=content&a=list&catid=295
+#     url = "http://spark.bokecc.com/api/playlog/video/v2"
+#     params_dict = {
+#         "userid": settings.COURSE_CC_USERID,
+#         "videoid": video_id,
+#         "date": date,
+#         "num_per_page": 5000,
+#         "page": 1
+#     }
+#     qs = thqs(params_dict, 'video')
+#     url += "?" + qs
+#     res = http_get(url)
+#     res_json = str2json(res)
+#     if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
+#         return res_json["total"], res_json["play_log"]
+#     return None, None
 
 
 # 获取日期内全部视频的观看记录
-def get_play_logs(date):
-    # https://doc.bokecc.com/index.php?c=content&a=list&catid=315
-    url = "http://spark.bokecc.com/api/playlog/user/v2"
-    params_dict = {
-        "userid": settings.COURSE_CC_USERID,
-        "date": date,
-        "num_per_page": 5000,
-        "page": 1
-    }
-    qs = thqs(params_dict, 'video')
-    url += "?" + qs
-    res = http_get(url)
-    res_json = str2json(res)
-    if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
-        return res_json["total"], res_json["play_log"]
-    return None, None
+# def get_play_logs(date):
+#     # https://doc.bokecc.com/index.php?c=content&a=list&catid=315
+#     url = "http://spark.bokecc.com/api/playlog/user/v2"
+#     params_dict = {
+#         "userid": settings.COURSE_CC_USERID,
+#         "date": date,
+#         "num_per_page": 5000,
+#         "page": 1
+#     }
+#     qs = thqs(params_dict, 'video')
+#     url += "?" + qs
+#     res = http_get(url)
+#     res_json = str2json(res)
+#     if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
+#         return res_json["total"], res_json["play_log"]
+#     return None, None
 
 
 # =================
@@ -426,28 +363,16 @@ def get_timestamp(_datetime):
     return timestamp
 
 
-# 排序，并转成字符串，用&链接
-def get_params_str(params_dict):
-    # 排序
-    s = sorted(params_dict.items(), key=lambda d: d[0])
-    print(s)
-
-    # tuple转字符串
-    # params_str_list = []
-    # for (key, value) in s:
-    #     if value:
-    #         params_str_list.append(key + "=" + value)
-    # params_str = "&".join(params_str_list)
-    # return params_str
-
 
 def thqs(params, type_str):
     # http://doc.bokecc.com/live/dev/liveapi/#toc_39
+    if not hasattr(settings, "CC_CONFIG"):
+        return
     qs = ""
     if type_str == 'live':
-        salt = settings.COURSE_CC_LIVE_APIKEY
+        salt = settings.CC_CONFIG.live_apikey
     else:
-        salt = settings.COURSE_CC_VIDEO_APIKEY
+        salt = settings.CC_CONFIG.video_apikey
 
     if params and len(params) > 0:
         sortd_params = sorted(params.iteritems(), key=lambda item: item[0])
@@ -469,24 +394,6 @@ def thqs(params, type_str):
     return hqs
 
 
-# 获取加密后的QueryString
-# type_str：live-直播apikey，video-点播video_apikey
-# params 加密的QueryString
-# def get_hashed_query_string(type_str, params_dict):
-#     timestamp = get_timestamp(dt.get_now())
-#     s = sorted(params_dict.items(), key=lambda d: d[0])
-#     params_dict[]
-#     params += "&time=" + timestamp.__str__()
-#     if type_str == 'live':
-#         apikey = live_apikey
-#     else:
-#         apikey = video_apikey
-#     print(apikey)
-#     params_str = params + "&salt=" + apikey
-#     print(params_str)
-#     hash_str = utils.str2md5(params_str)
-#     return urllib.urlencode(params + "&hash=" + hash_str)
-
 
 # 结果转json
 def str2json(res):
