@@ -32,24 +32,8 @@ def get_user_live_mins_count_days(user, start_dt=None, end_dt=None):
 
 
 def get_user_last_course_section(user, start_dt=None, end_dt=None):
-    ucs_list = UserCourseSection.objects.filter(user_course__user=user).order_by('-updated_at')
+    return UserCourseSection.get_user_last_course_section(user, start_dt=None, end_dt=None)
 
-    if ucs_list.exists():
-        if start_dt:
-            ucs_list = ucs_list.filter(updated_at__gte=start_dt)
-        if end_dt:
-            ucs_list = ucs_list.filter(updated_at__lte=end_dt)
-        list = ucs_list.filter(status=1)
-        if list.exists():
-            return list.first()
-        else:
-            finished = ucs_list.filter(status__in=[2, 4])
-            if finished.exists():
-                return finished.first()
-            else:
-                return None
-    else:
-        return None
 
 
 def get_current_user_course(user):
