@@ -737,6 +737,28 @@ class UserCourseSection(models.Model):
         return cls.objects.filter(user_course=user_course, status=2)
 
 
+    # 获取某时间段内学生学的最后一个课件
+    @classmethod
+    def get_user_last_course_section(cls,user, start_dt=None, end_dt=None):
+        ucs_list = cls.objects.filter(user_course__user=user).order_by('-updated_at')
+        if ucs_list.exists():
+            if start_dt:
+                ucs_list = ucs_list.filter(updated_at__gte=start_dt)
+            if end_dt:
+                ucs_list = ucs_list.filter(updated_at__lte=end_dt)
+            list = ucs_list.filter(status=1)
+            if list.exists():
+                return list.first()
+            else:
+                finished = ucs_list.filter(status__in=[2, 4])
+                if finished.exists():
+                    return finished.first()
+                else:
+                    return None
+        else:
+            return None
+
+
 class UserAssignment(models.Model):
     user_course_section = models.ForeignKey(UserCourseSection)
     content = models.TextField(verbose_name='正文', null=True, blank=True)  # 文字作业
