@@ -91,6 +91,8 @@ urlpatterns = [
     url(r'^live/video/(?P<user_live_id>(.)+)/$', views.live_video_detail, name='live_video_detail'),
     # 用户查看录播视频
     url(r'^user/live/(?P<user_live_id>(.)+)/$', views.user_live_video_detail, name='user_live_video_detail'),
+    # 记录助教观看录播视频
+    url(r'^user/live/update/view$', views.user_live_update_view, name='user_live_update_view'),
     # 编辑录播评论
     url(r'^user_live/comment/(?P<user_live_comment_id>\d+)/edit$', views.edit_user_live_comment,
         name='edit_user_live_comment'),
@@ -105,14 +107,15 @@ urlpatterns = [
 
     # 删除直播
     url(r'^delete_user_live/(?P<user_live_id>\d+)$', views.delete_user_live, name='delete_user_live'),
+    url(r'^user_live/star/update$', views.UserLiveStarUpdate.as_view(), name='user_live_star_update'),
 
     # 录播列表 = 前台
-    url(r'^custom_user_live/(?P<user_id>\d+)',views.CustomUserLivePage.as_view(),name='custom_user_live_page'),
+    url(r'^custom_user_live/(?P<user_id>\d+)', views.CustomUserLivePage.as_view(), name='custom_user_live_page'),
 
     # ====用户课程  后台 ===
     url(r'^user_course/(?P<user_id>\d+)$', views.UserCourseSectionRedirectView.as_view(), name='user_course'),
     # 用户学习的某一课程详情
-    url(r'^user_course/detail/(?P<user_course_id>\d+)$', views.UserCourseDetail.as_view(),
+    url(r'^user_course_detail/(?P<user_course_id>\d+)$', views.UserCourseDetail.as_view(),
         name='user_course_detail'),
     # 管理用户某一课程的列表
     url(r'^manage_user_course_section_list/(?P<user_course_id>\d+)$', views.manage_user_course_section_list,
@@ -129,7 +132,7 @@ urlpatterns = [
         name='custom_user_course'),
     url(r'^custom_user_course_detail/(?P<user_course_id>\d+)$', views.CustomUserCourseDetail.as_view(),
         name='custom_user_course_detail'),
-url(r'^custom_ucs_detail/(?P<pk>\d+)$', views.CustomUserCourseSectionDetail.as_view(),
+    url(r'^custom_ucs_detail/(?P<pk>\d+)$', views.CustomUserCourseSectionDetail.as_view(),
         name='custom_user_course_section_detail'),
 
     # 查看用户列表
