@@ -22,7 +22,7 @@ from .forms import CourseForm, SectionForm, CourseSectionForm, CourseSectionOrde
     UserCourseForm, UserAssignmentForm, UserAssignmentImageForm, SectionVideoForm, PreferenceForm, \
     section_attach_form, UserSectionNoteForm, SectionVideoOrderForm, LivePlayLogsForm, UserLiveCommentForm, \
     CourseSectionQuestionSearchForm, UserLiveSearchForm
-from .utils import JSONResponse, page_it, can_view_expired_live
+from .utils import JSONResponse, page_it, can_view_expired_live, live_finish
 from .cc import create_video_info, get_live_str
 from .cc import get_video_str as get_cc_video_str
 from .qiniu_api import get_video_str as get_qiniu_video_str
@@ -45,6 +45,9 @@ User = get_user_model()
 
 def test(request):
     # print('a', form)
+    from utils import gensee_vod_sync
+    a = gensee_vod_sync()
+    print a
     return render(request, 'bee_django_course/test_video.html')
 
 
@@ -921,6 +924,7 @@ class UserCourseDetail(ListView):
 
 
 class CustomUserCourseDetail(UserCourseDetail):
+
     def get_context_data(self, **kwargs):
         context = super(CustomUserCourseDetail, self).get_context_data(**kwargs)
         if self.user_course:
@@ -947,7 +951,7 @@ class CustomUserCourseDetail(UserCourseDetail):
                         ucs_dict['ucs_list'] = [i]
 
                 grouped_section_list.append(ucs_dict)
-                print(grouped_section_list)
+                # print(grouped_section_list)
                 context['grouped_section_list'] = grouped_section_list
 
         return context
@@ -964,6 +968,11 @@ class CustomUserCourseDetail(UserCourseDetail):
             # 特殊模版，各项目外重写html
             return 'bee_django_course/custom_user/custom_user_course_section_list_' + course.template + '.html'
 
+    def get_paginate_by(self, queryset):
+        if not self.user_course.course.template in [0, "0", None]:
+            self.paginate_by = 9999
+        return
+
 
 class CustomUserCourseList(ListView):
     template_name = 'bee_django_course/custom_user/custom_user_course_list.html'
@@ -1612,18 +1621,6 @@ def cc_live_end_callback(request):
 # return redirect(reverse_lazy('bee_django_crm:preuser_application_update_preuser', kwargs={'pk': preuser.id}))
 
 
-def save_coin_multiple(userlive):
-    coin_multiple = 1
-    r = random.randint(1, 1000)
-    if r >= 980:
-        coin_multiple = 3
-    elif r >= 900:
-        coin_multiple = 2
-    userlive.coin_multiple = coin_multiple
-    userlive.save()
-    return coin_multiple
-
-
 def set_preference(request):
     if Preference.objects.all().count() == 0:
         Preference.objects.create()
@@ -2167,26 +2164,6 @@ def test_video(request):
     return render(request, 'bee_django_course/test_video.html')
 
 
-# 直播转码完成后的一系列操作：更新课件进度，发送信号
-def live_finish(userlive, timedelta=None):
-    if not timedelta:
-        timedelta = userlive.duration
-    if timedelta < 60:
-        return
-
-    if not userlive.user:
-        return
-
-    # 更新课件学习时间
-    user_course_section = get_user_last_course_section(userlive.user)
-    if user_course_section:
-        user_course_section.update_work_time(timedelta / 60)
-        signals.ucs_update_time.send(sender=UserCourseSection, ucs=user_course_section)
-    coin_multiple = save_coin_multiple(userlive)
-    signals.live_callback_finished.send(sender=UserLive, user_live=userlive, coin_multiple=coin_multiple)
-    return
-
-
 @csrf_exempt
 def tencent_live_callback(request):
     # {"appid":1256935119,"channel_id":"aa","duration":3,"end_time":1562658284,"end_time_usec":453420,"event_type":100,"file_format":"mp4","file_id":"5285890791305792056","file_size":420382,"media_start_time":3801,"record_bps":0,"record_file_id":"5285890791305792056","start_time":1562658283,"start_time_usec":375858,"stream_id":"aa","stream_param":"txSecret=e939142722088dc59849bb82fc4d0fd1&txTime=5D24B9FF","task_id":"18288319047887901972","video_id":"1256935119_55156dda6162403abd8860da89d07ab6","video_url":"http://1256935119.vod2.myqcloud.com/8f802c2cvodcq1256935119/b3d83b505285890791305792056/f0.mp4"}
